@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import warnings
 
 import cv2
@@ -370,7 +371,7 @@ def post_dark_udp(coords, batch_heatmaps, kernel=3):
 
     index = coords[..., 0] + 1 + (coords[..., 1] + 1) * (W + 2)
     index += (W + 2) * (H + 2) * np.arange(0, B * K).reshape(-1, K)
-    index = index.astype(np.int).reshape(-1, 1)
+    index = index.astype(int).reshape(-1, 1)
     i_ = batch_heatmaps_pad[index]
     ix1 = batch_heatmaps_pad[index + 1]
     iy1 = batch_heatmaps_pad[index + W + 2]
@@ -577,7 +578,7 @@ def keypoints_from_heatmaps(heatmaps,
             preds, maxvals = _get_max_preds(heatmaps)
             index = preds[..., 0] + preds[..., 1] * W
             index += W * H * np.arange(0, N * K / 3)
-            index = index.astype(np.int).reshape(N, K // 3, 1)
+            index = index.astype(int).reshape(N, K // 3, 1)
             preds += np.concatenate((offset_x[index], offset_y[index]), axis=2)
         else:
             raise ValueError('target_type should be either '
@@ -671,7 +672,7 @@ def multilabel_classification_accuracy(pred, gt, mask, thr=0.5):
     pred, gt = pred[valid], gt[valid]
 
     if pred.shape[0] == 0:
-        acc = 0  # when no sample is with gt labels, set acc to 0.
+        acc = 0.0  # when no sample is with gt labels, set acc to 0.
     else:
         # The classification of a sample is regarded as correct
         # only if it's correct for all labels.
