@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 from mmcv.cnn import build_model_from_cfg
 from mmcv.utils import Registry
 
@@ -8,6 +9,7 @@ NECKS = MODELS
 HEADS = MODELS
 LOSSES = MODELS
 POSENETS = MODELS
+MESH_MODELS = MODELS
 
 
 def build_backbone(cfg):
@@ -33,3 +35,8 @@ def build_loss(cfg):
 def build_posenet(cfg):
     """Build posenet."""
     return POSENETS.build(cfg)
+
+
+def build_mesh_model(cfg):
+    """Build mesh model."""
+    return MESH_MODELS.build(cfg)
